@@ -15,14 +15,14 @@ clean () {
 	rm -rf $WORKING_DIR
 }
 
-git clone git://sentinella.git.sourceforge.net/gitroot/sentinella/sentinella -b v${DOTTED_VERSION%.*} sentinella-$DOTTED_VERSION
+mkdir -p $WORKING_DIR
+cd $WORKING_DIR
+
+git clone git://git.code.sf.net/p/sentinella/code -b v${DOTTED_VERSION%.*} sentinella-$DOTTED_VERSION
 cd sentinella-$DOTTED_VERSION
 git checkout v$DOTTED_VERSION
 cd ..
 
-mkdir -p $WORKING_DIR
-mv sentinella-$DOTTED_VERSION $WORKING_DIR
-
 read -p "Have you updated the version in main.cpp? (y/n) " yn
 if  [ $yn != "y" ]; then
 	clean
