@@ -1,7 +1,7 @@
 /*
  * Sentinella
  * http://sentinella.sourceforge.net/
- * Copyright (c) 2009-2011 Carlos Olmedo Escobar <carlos.olmedo.e@gmail.com>
+ * Copyright (c) 2009-2012 Carlos Olmedo Escobar <carlos.olmedo.e@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -54,7 +54,7 @@
 
 MainWindow::MainWindow(KCmdLineArgs* cmdLineArgs, const ConditionId cmdChosenCondition,
 		const ActionId cmdChosenAction) :
-	KMainWindow(NULL, Qt::WindowContextHelpButtonHint | Qt::WindowCloseButtonHint), cmdLineArgs(
+		KMainWindow(NULL, Qt::WindowContextHelpButtonHint | Qt::WindowCloseButtonHint | Qt::WindowMinimizeButtonHint), cmdLineArgs(
 			cmdLineArgs) {
 	condition = NULL;
 	action = NULL;
@@ -461,8 +461,11 @@ void MainWindow::startCondition() {
 			KMessageBox::sorry(this, i18n("You must select a program to kill."));
 			return;
 		}
-		if (!processExists(pidKillProcess))
+		if (!processExists(pidKillProcess)) {
+			pidKillProcess = 0;
+			gui.labelKillProcess->clear();
 			return;
+		}
 		break;
 	default:
 		break;
@@ -524,8 +527,11 @@ void MainWindow::startCondition() {
 			KMessageBox::sorry(this, i18nc("@info", "You must select a program to monitor."));
 			return;
 		}
-		if (!processExists(pidProcessDies))
+		if (!processExists(pidProcessDies)) {
+			pidProcessDies = 0;
+			gui.labelProcessDies->clear();
 			return;
+		}
 		condition = new ProcessDies(processAPI, 2000, 2000, pidProcessDies);
 	}
 
@@ -655,6 +661,8 @@ void MainWindow::conditionAccomplished() {
 		action = new KillProcess(pidKillProcess);
 		KPassivePopup::message(PASSIVE_POPUP_TITLE, i18nc("@info",
 				"Condition met. Killing the selected program."), this);
+		pidKillProcess = 0;
+		gui.labelKillProcess->clear();
 	}
 	action->execute();
 
@@ -666,6 +674,16 @@ void MainWindow::conditionAccomplished() {
 		delete action;
 		action = NULL;
 	}
+
+	ConditionId conditionCheckedId = (ConditionId) conditionsGroup.checkedId();
+	switch (conditionCheckedId) {
+	case PROCESSDIES:
+		pidProcessDies = 0;
+		gui.labelProcessDies->clear();
+		break;
+	default:
+		break;
+	}
 }
 
 void MainWindow::conditionFailed(int error) {
@@ -744,7 +762,7 @@ bool MainWindow::createProcess() {
 }
 
 bool MainWindow::processExists(pid_t pid) {
-	if (processAPI == NULL || !createProcess())
+	if (processAPI == NULL && !createProcess())
 		return false;
 	if (processAPI->processExists(pid))
 		return true;
@@ -753,7 +771,7 @@ bool MainWindow::processExists(pid_t pid) {
 }
 
 bool MainWindow::getProcess(struct sa_process* procInfo) {
-	if (processAPI == NULL || !createProcess())
+	if (processAPI == NULL && !createProcess())
 		return false;
 	processAPI->getProcess(procInfo);
 	if (processAPI->error) {
