@@ -1,7 +1,7 @@
 /*
  * Sentinella
  * http://sentinella.sourceforge.net/
- * Copyright (c) 2009-2011 Carlos Olmedo Escobar <carlos.olmedo.e@gmail.com>
+ * Copyright (c) 2009-2012 Carlos Olmedo Escobar <carlos.olmedo.e@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,11 +27,11 @@
 #include "MainWindow.h"
 
 int main(int argc, char **argv) {
-	KAboutData aboutData("sentinella", NULL, ki18n("Sentinella"), "0.9.0", ki18n(
+	KAboutData aboutData("sentinella", NULL, ki18n("Sentinella"), "0.9.1", ki18n(
 			"Action launcher based on system activity"), KAboutData::License_GPL_V2, ki18n(
-			"Copyright (c) 2009-2011 Carlos Olmedo Escobar"), ki18n(""),
+			"Copyright (c) 2009-2012 Carlos Olmedo Escobar"), ki18n(""),
 			"http://sentinella.sourceforge.net/",
-			"http://sourceforge.net/tracker/?func=add&group_id=277778&atid=1179456");
+			"https://sourceforge.net/p/sentinella/bugs/new/");
 	aboutData.addAuthor(ki18n("Carlos Olmedo Escobar"), ki18n("Project leader."),
 			"carlos.olmedo.e@gmail.com");
 	aboutData.addCredit(ki18n("Damon John Hoxworth"), ki18n("Web designer"),
@@ -47,7 +47,7 @@ int main(int argc, char **argv) {
 	options.add("s").add("start", ki18n("The condition will be run immediately."));
 
 	options.add(":", ki18n("Condition options:"));
-	options.add("cpu <percentage>", ki18n(
+	options.add("cpu <percentage>", ki18nc("@info Keep '--during', '--lower' and '--higher' in english",
 			"CPU load measurement. Use in combination with --during, --lower or --higher."));
 	options.add("memory <megabytes>", ki18n(
 			"Memory usage in megabytes. Use in combination with --during, --lower or --higher."));
